import { closeConnection } from './closeConnection';
import { sendResponse } from './sendResponse';
export class WsApi {
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    routeHandlers = {
        '$connect': () => Promise.resolve(),
        '$disconnect': () => Promise.resolve(),
    };
    addRouteHandler(routeHandler) {
        this.routeHandlers[routeHandler.route.action] = routeHandler.requestHandler;
        return this;
    }
    async handleRequest(event) {
        const { body } = event;
        const { connectionId, domainName, stage, routeKey } = event.requestContext;
        if (!routeKey)
            throw 'No routeKey';
        if (!connectionId)
            throw 'No connectionId';
        if (!domainName)
            throw 'No domainName';
        let action = routeKey;
        let request = { action: routeKey };
        if (routeKey === '$default') {
            if (!body)
                throw 'No body';
            request = JSON.parse(body);
            action = request.action;
            if (!action)
                throw 'No routeKey/action';
        }
        const endpoint = `https://${domainName}/${stage}`;
        const connection = { endpoint, connectionId };
        const requestHandler = this.routeHandlers[action];
        if (!requestHandler) {
            await closeConnection(connection);
            throw `No requestHandler found for action ${action}`;
        }
        await requestHandler(request, {
            connection,
            sendResponse: async (response) => await sendResponse(connection, response),
            closeConnection: async () => await closeConnection(connection),
        });
        return {
            statusCode: 200,
            body: '',
        };
    }
}
//# sourceMappingURL=WsApi.js.map